@@ -38,9 +38,10 @@ iteration of the algorithm to the population it takes as input
 
 package Algorithm::Evolutionary::Op::Easy_MO;
 
-our ($VERSION) = ( '$Revision: 3.6 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp;
+use Clone::Fast qw(clone);
 
 use Algorithm::Evolutionary qw( Wheel Op::Bitflip
 				Op::Crossover
@@ -51,14 +52,13 @@ use base 'Algorithm::Evolutionary::Op::Base';
 # Class-wide constants
 our $APPLIESTO =  'ARRAY';
 
-=head2 new( $eval_func, [$selection_rate,] [$operators_arrayref] )
+=head2 new( $eval_func, [$operators_arrayref] )
 
 Creates an algorithm that optimizes the handled fitness function and
 reference to an array of operators. If this reference is null, an
 array consisting of bitflip mutation and 2 point crossover is
-generated. Which, of course, might not what you need in case you don't
-have a binary chromosome. Take into account that in this case the
-fitness function should return a reference to array. 
+generated. Which, of course, might not what you need in case you
+don't have a binary chromosome.
 
 =cut
 
@@ -130,9 +130,7 @@ sub apply ($) {
 
   #Cull
   my $pringaos = int(($#popsort+1)*$self->{_selrate}); #+1 gives you size
-#  print "Pringaos $pringaos\n";
-  splice @popsort, - $pringaos;
-#  print "Poblacin ", scalar @popsort, "\n";
+  splice @popsort, $#popsort - $pringaos, $pringaos;
  
   #Reproduce
   my @rates = map( $_->{'rate'}, @ops );
@@ -164,17 +162,17 @@ sub apply ($) {
 
 L<Algorithm::Evolutionary::Op::CanonicalGA>.
 L<Algorithm::Evolutionary::Op::FullAlgorithm>.
-L<Algorithm::Evolutionary::Op::Easy> for the scalar version of this code.
+
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy_MO.pm,v 3.6 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/24 08:46:59 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy_MO.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.6 $
+  $Revision: 3.0 $
   $Name $
 
 =cut
